@@ -17,7 +17,7 @@
 
 /****************************************************************************/
 
-#include "threaddep/penguin.h"
+#include "threaddep/thread.h"
 #include "uae.h"
 #include "config.h"
 #include "options.h"
@@ -526,7 +526,8 @@ int graphics_init(void)
         return 0;
     }
 
-    gfxvidinfo.linemem  = NULL;
+    gfxvidinfo.emergmem = 0;
+    gfxvidinfo.linemem = 0;
     gfxvidinfo.rowbytes = gfxvidinfo.pixbytes * currprefs.gfx_width;
     gfxvidinfo.bufmem = (char *)calloc(gfxvidinfo.rowbytes, 
                                        currprefs.gfx_height);
@@ -951,11 +952,6 @@ static void disk_hotkeys(void)
     }
 }
 
-void write_log (const char *buf)
-{
-    fprintf (stderr, buf);
-}
-
 /****************************************************************************/
 
 ULONG pOS_GetObjectData(APTR obj,ULONG tag)
